#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?tmpfiles_create:%global tmpfiles_create systemd-tmpfiles --create}
# baseversion - version of kubernetes for this package
%define baseversion 1.24
%define baseversionminus1 1.23

Name:           kubernetes%{baseversion}
Version:        1.24.17
Release:        150500.3.28.1
Summary:        Container Scheduling and Management
License:        Apache-2.0
Group:          System/Management
URL:            https://kubernetes.io/
Source:         kubernetes-%{version}.tar.xz
Source2:        genmanpages.sh
Source3:        kubelet.sh
#systemd services
Source10:       kubelet.service
#config files
Source22:       sysconfig.kubelet-kubernetes
Source23:       kubeadm.conf
Source24:       90-kubeadm.conf
Source25:       10-kubeadm.conf
Source27:       kubelet.tmp.conf
Source28:       kubernetes-rpmlintrc
Source29:       kubernetes.obsinfo
# Patch to change the default registry to registry.opensuse.org/kubic
Patch2:         kubeadm-opensuse-registry.patch
# Patch to change the version check server to kubic.opensuse.org
Patch3:         opensuse-version-checks.patch
# Patch to change the default flexvolume path in kubeadm to match that used by our kubelet, else kubeadm tries to write to /usr when kubelet is already looking at a path on /var thanks to the fix to bsc#1084766
Patch4:         kubeadm-opensuse-flexvolume.patch
# Patch to revert renaming of coredns image location to match how it's done on download.opensuse.org
Patch5:         revert-coredns-image-renaming.patch
# Patch to fix reproducible builds https://github.com/kubernetes/kubernetes/issues/110928
Patch6:         kubernetes-trimpath.patch
# Patch to advance autoscaling v2 as the preferred API version, to fix bsc#1219964, CVE-2024-0793
Patch7:         autoscaling-advance-v2-as-the-preferred-API-version.patch
# Patch to fix CVE-2024-3177, for bypassing mountable secrets policy imposed by the ServiceAccount admission plugin
Patch8:         bypass-mountable-secrets-policy-imposed-by-SA-admission-plugin.patch
# Patch to fix CVE-2021-25743, to escape terminal special characters in kubectl output
Patch9:         escape-terminal-special-characters-in-kubectl-112553.patch
# Patch to fix CVE-2024-24786, bump github.com/golang/protobuf v1.5.4, google.golang.org/protobuf v1.33.0
Patch10:        bump-golang-protobuf-to-v1_5_4.patch
# Patch to fix CVE-2023-45288, bump x/net to v0.23.0
Patch11:        bump-x-net-to-v0_23_0.patch
# Mitigates http/2 DOS vulnerabilities for CVE-2023-44487 and CVE-2023-39325 for the API server when the client is unauthenticated. The mitigation may be disabled by setting the `UnauthenticatedHTTP2DOSMitigation` feature gate to `false` (it is enabled by default). An API server fronted by an L7 load balancer that already mitigates these http/2 attacks may choose to disable the kube-apiserver mitigation to avoid disrupting load balancer → kube-apiserver connections if http/2 requests from multiple clients share the same backend connection. An API server on a private network may opt to disable the kube-apiserver mitigation to prevent performance regressions for unauthenticated clients. Authenticated requests rely on the fix in golang.org/x/net v0.17.0 alone. https://issue.k8s.io/121197 tracks further mitigation of http/2 attacks by authenticated clients.
Patch12:        prevent-rapid-reset-http2-DOS-on-API-server.patch
Patch13:        bump-golang-org-grpc-to-v1_56_3.patch
Patch14:        expose-DisableHTTP2-flag-in-SecureServingOptions.patch
# Patch to fix CVE-2025-22872, properly handle trailing solidus in unquoted attribute value in foreign content
# Ref: https://go.googlesource.com/net/+/e1fcd82abba34df74614020343be8eb1fe85f0d9
Patch15:         cve-2025-22872-x-net-html-properly-handle-trailing-solidus.patch
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  go >= 1.22.5
BuildRequires:  go-go-md2man
BuildRequires:  golang-packaging
BuildRequires:  rsync
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) = 1.22
BuildRequires:  golang(github.com/jteeuwen/go-bindata)
ExcludeArch:    %{ix86} s390 ppc64

%description
Kubernetes is a system for automating deployment, scaling, and
management of containerized applications.

It groups containers that make up an application into logical units
for management and discovery.


# packages to build containerized control plane
%package apiserver
Summary:        Kubernetes apiserver for container image
Group:          System/Management
Provides:       kubernetes-apiserver-provider = %{version}
Conflicts:      kubernetes-apiserver-provider

%description apiserver
This subpackage contains the kube-apiserver binary for Kubic images

%package controller-manager
Summary:        Kubernetes controller-manager for container image
Group:          System/Management
Provides:       kubernetes-controller-manager-provider = %{version}
Conflicts:      kubernetes-controller-manager-provider

%description controller-manager
This subpackage contains the kube-controller-manager binary for Kubic images

%package scheduler
Summary:        Kubernetes scheduler for container image
Group:          System/Management
Provides:       kubernetes-scheduler-provider = %{version}
Conflicts:      kubernetes-scheduler-provider

%description scheduler
This subpackage contains the kube-scheduler binary for Kubic images

%package proxy
Summary:        Kubernetes proxy for container image
Group:          System/Management
Provides:       kubernetes-proxy-provider = %{version}
Conflicts:      kubernetes-proxy-provider
Requires:       conntrack-tools
Requires:       ebtables
Requires:       ipset
Requires:       iptables

%description proxy
This subpackage contains the kube-proxy binary for Kubic images

%package kubelet
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet-common
Recommends:     kubernetes-kubelet-common = %{version}
Provides:       kubernetes-kubelet%{baseversion} = %{version}
Obsoletes:      kubernetes-kubelet%{baseversion} < %{version}
%{?systemd_requires}

%description kubelet
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon (current version)

%package kubelet-common
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet%{baseversion}
Provides:       kubernetes-kubelet-common = %{version}
Conflicts:      kubernetes-kubelet-common

%description kubelet-common
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon

%package kubeadm
Summary:        Kubernetes kubeadm bootstrapping tool
Group:          System/Management
Provides:       kubernetes-kubeadm-provider = %{version}
Conflicts:      kubernetes-kubeadm-provider
Obsoletes:      kubernetes%{baseversionminus1}-kubeadm
Requires:       cri-runtime
Requires:       cri-tools
Requires:       ebtables
Requires:       ethtool
Requires:       kubernetes-kubeadm-criconfig
Requires:       socat
Requires(pre):  shadow
Requires:       (kubernetes%{baseversion}-kubelet or kubernetes%{baseversionminus1}-kubelet)
Recommends:     kubernetes%{baseversion}-kubelet

%description kubeadm
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubeadm bootstrapping tool

%package client
Summary:        Kubernetes client tools
Group:          System/Management
Provides:       kubernetes-client-provider = %{version}
Requires:       kubernetes%{baseversion}-client-common
Requires(post): update-alternatives
Requires(postun):update-alternatives

%description client
Kubernetes client tools like kubectl.

%package client-common
Summary:        Kubernetes client tools common files
Group:          System/Management
Requires:       kubernetes%{baseversion}-client
Provides:       kubernetes-client-common = %{version}
Conflicts:      kubernetes-client-common

%description client-common
Kubernetes client tools common files

%package client-bash-completion
Summary:        Bash Completion for %{name}-client
Group:          System/Shells
BuildRequires:  bash-completion
Requires:       bash-completion
Requires:       kubernetes%{baseversion}-client  = %{version}
Supplements:    (kubernetes%{baseversion}-client and bash-completion)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-bash-completion
Provides:       kubernetes-client-bash-completion = %{version}
Conflicts:      kubernetes-client-bash-completion
Conflicts:      kubernetes1.18-client-common

%description client-bash-completion
Bash command line completion support for %{name}-client

%package client-fish-completion
Summary:        Fish Completion for %{name}-client
Group:          System/Shells
BuildRequires:  fish
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and fish)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-fish-completion
Provides:       kubernetes-client-fish-completion = %{version}
Conflicts:      kubernetes-client-fish-completion

%description client-fish-completion
Fish command line completion support for %{name}-client.

%prep
%setup -q -n kubernetes-%{version}
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p0
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 9 -p1
%patch -P 10 -p1
%patch -P 11 -p1
%patch -P 12 -p1
%patch -P 13 -p1
%patch -P 14 -p1
%patch -P 15 -p1

%build
# This is fixing bug bsc#1065972
export KUBE_GIT_COMMIT=$(grep "commit:" %{SOURCE29} | cut -d ":" -f2 | tr -d " ")
# KUBE_GIT_TREE_STATE="clean" indicates no changes since the git commit id
# KUBE_GIT_TREE_STATE="dirty" indicates source code changes after the git commit id
export KUBE_GIT_TREE_STATE="clean"
export KUBE_GIT_VERSION=v%{version}

# https://bugzilla.redhat.com/show_bug.cgi?id=1392922#c1
#%ifarch ppc64le
#export GOLDFLAGS='-linkmode=external'
#%endif

#TEST
%ifarch s390x
# `-buildmode=pie` with "internal linking" is not yet supported on linux/s390x platform
# https://github.com/golang/go/blob/a63907808d14679c723e566cb83acc76fc8cafc2/src/internal/platform/supported.go#L223-L232
# https://github.com/golang/go/issues/64875#issuecomment-1870734528
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm"
%else
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm" GOFLAGS="-buildmode=pie"
%endif

# The majority of the documentation has already been moved into
# http://kubernetes.io/docs/admin, and most of the files stored in the `docs`
# directory simply point there. That being said, some of the files are actual
# man pages, but they have to be generated with `hack/generate-docs.sh`. So,
# let's do that and run `genmanpages.sh`.
./hack/generate-docs.sh || true
pushd docs
pushd admin
cp kube-apiserver.md kube-controller-manager.md kube-proxy.md kube-scheduler.md kubelet.md ..
popd
cp %{SOURCE2} genmanpages.sh
bash genmanpages.sh
popd

%install

%ifarch ppc64le aarch64
output_path="_output/local/go/bin"
%else
output_path="_output/local/bin/linux/%{go_arch}"
%endif

install -m 755 -d %{buildroot}%{_bindir}

echo "+++ INSTALLING kubeadm"
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/kubeadm

binaries=(kube-apiserver kube-controller-manager kube-scheduler kube-proxy)
for bin in "${binaries[@]}"; do
  echo "+++ INSTALLING ${bin}"
  install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/${bin}
done

for bin in kubelet kubectl; do
  echo "+++ INSTALLING ${bin} with %{baseversion} suffix"
  install -p -m 755 ${output_path}/${bin} %{buildroot}%{_bindir}/${bin}%{baseversion}
done

echo "+++ INSTALLING kubelet multi-version loader"
install -p -m 755 %{SOURCE3} %{buildroot}%{_bindir}/kubelet

# create sysconfig.kubelet-kubernetes in fullupdir
sed -i -e 's|BASE_VERSION|%{baseversion}|g' %{SOURCE22}
install -D -m 0644 %{SOURCE22} %{buildroot}%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# install the bash completion
install -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions/
%{buildroot}%{_bindir}/kubectl%{baseversion} completion bash > %{buildroot}%{_datadir}/bash-completion/completions/kubectl

# install the fish completion
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}%{_bindir}/kubectl%{baseversion} completion fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/kubectl.fish

# move CHANGELOG-%{baseversion}.md to old location
mv CHANGELOG/CHANGELOG-%{baseversion}.md .

# cleanup before copying dirs...
rm -f hack/.linted_packages
find .    -name '.gitignore' -type f -delete
find hack -name '*.sh.orig' -type f -delete
find hack -name '.golint_*' -type f -delete

# systemd service
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 -t %{buildroot}%{_unitdir}/ %{SOURCE10}

# make symlinks to rc files
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf service "%{buildroot}%{_sbindir}/rckubelet"

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 docs/man/man1/* %{buildroot}%{_mandir}/man1

# create config folder
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}

# manifests file for the kubelet
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests

# place kubernetes.tmp.conf to /usr/lib/tmpfiles.d/kubernetes.conf
install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -D -m 0644 %{SOURCE27} %{buildroot}/%{_tmpfilesdir}/kubelet.conf

# install the place the kubelet defaults to put volumes
install -d %{buildroot}%{_localstatedir}/lib/kubelet

%define volume_plugin_dir %{_localstatedir}/lib/kubelet/volume-plugin
install -d %{buildroot}/%{volume_plugin_dir}

# Add kubeadm modprobe.d and sysctl.d drop-in configs
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
mkdir -p %{buildroot}%{_sysctldir}
install -m 0644 -t %{buildroot}%{_prefix}/lib/modules-load.d/ %{SOURCE23}
install -m 0644 -t %{buildroot}%{_sysctldir} %{SOURCE24}

# Create kubeadm systemd unit drop-in
install -d -m 0755 %{buildroot}%{_unitdir}/kubelet.service.d
sed -i -e 's|PATH_TO_FLEXVOLUME|%{volume_plugin_dir}|g' %{SOURCE25}
install -m 0644 -t %{buildroot}%{_unitdir}/kubelet.service.d/ %{SOURCE25}

# alternatives
ln -s -f %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%fdupes -s %{buildroot}

%post client-common
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kubectl%{baseversion} %(echo %{baseversion} | tr -d .)

%postun client-common
if [ ! -f %{_bindir}/kubectl%{baseversion} ] ; then
  update-alternatives --remove kubectl %{_bindir}/kubectl%{baseversion}
fi

%pre kubelet-common
%service_add_pre kubelet.service

%post kubelet-common
%fillup_only -an kubelet
# Check if /etc/sysconfig/kubelet exists
if [ -e "/etc/sysconfig/kubelet" ]; then
  # Extract the value from the fillup file
  UPDATED_KUBELET_VER=$(grep '^KUBELET_VER=' %{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion} | cut -d '=' -f2)
  # Update the value in the sysconfig file
  sed -i "s/^KUBELET_VER=.*/KUBELET_VER=$UPDATED_KUBELET_VER/" /etc/sysconfig/kubelet
fi
%service_add_post kubelet.service
if [ $1 -eq 1 ]; then
    # Check if modprobe command is available
    [ ! -x /sbin/modprobe ] || { /sbin/modprobe br_netfilter && /sbin/modprobe overlay; } || true
fi
%if 0%{?suse_version} < 1500
# create some subvolumes needed by CNI
if [ ! -e %{_localstatedir}/lib/cni ]; then
  if [ "`findmnt -o FSTYPE -l  /|grep -v FSTYPE`" = "btrfs" ]; then
    %{_sbindir}/mksubvolume %{_localstatedir}/lib/cni
  fi
fi
%endif
%tmpfiles_create %{_tmpfilesdir}/kubelet.conf

%preun kubelet-common
%service_del_preun kubelet.service

%postun kubelet-common
%service_del_postun kubelet.service

%post kubeadm
# Check if sysctl command is available
if [ -x /usr/sbin/sysctl ]; then
    # Run sysctl --system after the package installation
    /usr/sbin/sysctl -p %{_sysctldir}/90-kubeadm.conf || true
fi

%files kubelet-common
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%license LICENSE
%{_mandir}/man1/kubelet.1%{?ext_man}
%{_bindir}/kubelet
%{_unitdir}/kubelet.service
%dir %{_unitdir}/kubelet.service.d
%{_sbindir}/rckubelet
%dir %{_localstatedir}/lib/kubelet
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/manifests
%{_tmpfilesdir}/kubelet.conf
%attr(0750,root,root) %dir %ghost %{_rundir}/%{name}
%dir %{volume_plugin_dir}
%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# openSUSE is using kubeadm with containerizied control plane, we
# only need the binaries

%files apiserver
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-apiserver.1%{?ext_man}
%{_bindir}/kube-apiserver

%files controller-manager
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-controller-manager.1%{?ext_man}
%{_bindir}/kube-controller-manager

%files scheduler
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-scheduler.1%{?ext_man}
%{_bindir}/kube-scheduler

%files proxy
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-proxy.1%{?ext_man}
%{_bindir}/kube-proxy

%files kubelet
%license LICENSE
%{_bindir}/kubelet%{baseversion}

%files kubeadm
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%{_unitdir}/kubelet.service.d/10-kubeadm.conf
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/kubeadm.conf
%{_sysctldir}/90-kubeadm.conf
%license LICENSE
%{_bindir}/kubeadm
%{_mandir}/man1/kubeadm*

%files client
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_bindir}/kubectl
%{_bindir}/kubectl%{baseversion}
%ghost %_sysconfdir/alternatives/kubectl

%files client-common
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kubectl.1%{?ext_man}
%{_mandir}/man1/kubectl-*

%files client-bash-completion
%{_datadir}/bash-completion/completions/kubectl

%files client-fish-completion
%{_datadir}/fish/vendor_completions.d/kubectl.fish

%changelog
* Tue Jun 10 2025 priyanka.saggu@suse.com
- add patch file: cve-2025-22872-x-net-html-properly-handle-trailing-solidus.patch
  * fixes CVE-2025-22872, bsc#1241865
  * Ref: https://github.com/golang/net/commit/e1fcd82abba34df74614020343be8eb1fe85f0d9
* Fri Sep 13 2024 priyanka.saggu@suse.com
- Security fix for bsc#1229869
  * New Patches:
  - prevent-rapid-reset-http2-DOS-on-API-server.patch,
  - bump-golang-org-grpc-to-v1_56_3.patch,
  - expose-DisableHTTP2-flag-in-SecureServingOptions.patch
  * Mitigates http/2 DOS vulnerabilities for CVE-2023-44487 and CVE-2023-39325 for the API server when the client is unauthenticated. The mitigation may be disabled by setting the `UnauthenticatedHTTP2DOSMitigation` feature gate to `false` (it is enabled by default). An API server fronted by an L7 load balancer that already mitigates these http/2 attacks may choose to disable the kube-apiserver mitigation to avoid disrupting load balancer → kube-apiserver connections if http/2 requests from multiple clients share the same backend connection. An API server on a private network may opt to disable the kube-apiserver mitigation to prevent performance regressions for unauthenticated clients. Authenticated requests rely on the fix in golang.org/x/net v0.17.0 alone. https://issue.k8s.io/121197 tracks further mitigation of http/2 attacks by authenticated clients.
* Thu Sep 12 2024 priyanka.saggu@suse.com
- Update .spec file to bump go version build requirements (per requested in bsc#1229858)
  * `BuildRequires:  go >= 1.22.5`
  * `BuildRequires:  golang(API) = 1.22`
- Follow up changes after go version bump to 1.22:
  - For ppc64le platform: disabled `export GOLDFLAGS='-linkmode=external'`.
  * to fix the build failure error:
    `-linkmode=external requires external (cgo) linking, but cgo is not enabled`
  - For linux/s390x platform: disabled building kubernetes binaries with `-buildmode=pie`
  * `-buildmode=pie` with "internal linking" is not yet supported on linux/s390x platform
  * ref: https://github.com/golang/go/blob/a63907808d14679c723e566cb83acc76fc8cafc2/src/internal/platform/supported.go#L223-L232
  * ref: https://github.com/golang/go/issues/64875#issuecomment-1870734528
* Thu Sep 12 2024 priyanka.saggu@suse.com
- Security fix for bsc#1229869
  * New Patch: bump-x-net-to-v0_23_0.patch
  - golang.org/x/net is bumped to v0.23.0 to address CVE-2023-45288
* Thu Sep 12 2024 priyanka.saggu@suse.com
- Security fix for bsc#1229867
  * New Patch: bump-golang-protobuf-to-v1_5_4.patch
  - [CVE-2024-24786] Bump github.com/golang/protobuf v1.5.4, google.golang.org/protobuf v1.33.0
* Tue Aug  6 2024 priyanka.saggu@suse.com
- add new security patch to escape terminal special characters in kubectl output, bsc#1194400, CVE-2021-25743
  * patch file - escape-terminal-special-characters-in-kubectl-112553.patch
* Wed Apr 10 2024 priyanka.saggu@suse.com
- add new security patch for bypassing mountable secrets policy imposed by the ServiceAccount admission plugin,
  bsc#1222539, CVE-2024-3177
  * patch file – bypass-mountable-secrets-policy-imposed-by-SA-admission-plugin.patch
* Mon Feb 26 2024 priyanka.saggu@suse.com
- add new patch to advance autoscaling v2 as the preferred API version, to fix bsc#1219964, CVE-2024-0793
  * autoscaling-advance-v2-as-the-preferred-API-version.patch
* Thu Feb 22 2024 dimstar@opensuse.org
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Jan  3 2024 bwiedemann@suse.com
- Add kubernetes-trimpath.patch for reproducible builds (boo#1062303)
* Wed Sep 20 2023 priyanka.saggu@suse.com
- fixes for bsc#1214406
- update `Wants` directive in [Unit] section of `kubelet.service`:
  * add: `containerd.service`
  * remove: `docker.service`
- updating container runtime prerequisites:
  (Refer: k8s.io/docs/setup/production-environment/container-runtimes/#install-and-configure-prerequisites)
  * update `90-kubeadm.conf` to add below iptables rules:
  - net.bridge.bridge-nf-call-iptables = 1
  - net.bridge.bridge-nf-call-ip6tables = 1
  * update `kubeadm.conf` to add `overlay` kernel module
  * update .spec file to:
  - add post-installation scriptlet for `kubeadm` package to enable iptables rules defined in `90-kubeadm.conf` using sysctl
  - add conditional checks to load kernel modules (br_netfilter, overlay) in `kubelet-common` package post-installation scriptlet
  - update `kubelet-common` post scriptlet to correctly update `KUBELET_VER` var in `/etc/sysconfig/kubelet` file based on fillup template
- add below to `kubelet` subpackage to recommend installing correct version of package providing `kubernetes-kubelet-common` :
  * `Recommends: kubernetes-kubelet-common = %%{version}`
- add below to `kubeadm` subpackage to recommend installing correct version of `kubelet` and `kubelet-common` packages:
  * `Recommends: kubernetes%%{baseversion}-kubelet`
* Tue Sep 12 2023 priyanka.saggu@suse.com
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.20.7`
- Update to version 1.24.17:
  * Release commit for Kubernetes v1.24.17
  * Use environment varaibles for parameters in Powershell
  * Use env varaibles for passing path
  * Fix capture loop vars in parallel or ginkgo tests
  * Update protoc check for verify-generated-kms
  * [release-1.24] releng/go: Bump images, versions and deps to use Go 1.20.7
  * Update CHANGELOG/CHANGELOG-1.24.md for v1.24.16
  * kmsv1: attempt AES-GCM before AES-CBC on reads
* Wed Jul 26 2023 priyanka.saggu@suse.com
- Update: `BuildRequires:  go >= 1.20.6`
- Update: `BuildRequires:  golang(API) = 1.20`
- Update to version 1.24.16:
  * [release-1.24] releng/go: Bump images, versions and deps to use Go 1.20.6
  * Fix the converts an empty string to nil.
  * Only declare job as finished after removing all finalizers
  * Fix deadlock in ready test
  * deps: Bump to cAdvisor v0.44.2
  * Fix the git-repo test error caused by the correct use of loop variables
  * kubeadm: remove function pointer comparison in phase test
  * test server side apply patch
  * don't process unsupported loadbalancers with mixed protocols
  * make MixedProtocolNotSupported public
* Tue Jun 20 2023 priyanka.saggu@suse.com
- remove: kube-apiserver-admission-plugin-policy.patch
  * patch included upstream in the v1.24.15 patch version release
- remove: kubernetes1.24.13.obscpio
* Thu Jun 15 2023 priyanka.saggu@suse.com
- v1.24.15 includes Security Patch Fix for CVE-2023-2727 (bsc#1211630) and CVE-2023-2728 (bsc#1211631)
- Update: `BuildRequires:  go >= 1.19.10`
- Update to version 1.24.15:
  * Release commit for Kubernetes v1.24.15
  * update-vendor: update vendored go.sums
  * [release-1.24] releng/go: Update images, deps and ver to go 1.19.10
  * kube-proxy avoid race condition using LocalModeNodeCIDR
  * Add ephemeralcontainer to imagepolicy securityaccount admission plugin
  * Switch to assert.ErrorEquals from assert.Equal to check error equality
  * kubeadm: Make etcd member removal idempotent
  * kubeadm: Add etcd client unit tests
  * kubeadm: Use internal etcd client through an interface
  * update webhook test to go 1.21
  * Test APIService safe handling at startup
  * Fix waiting for CRD sync at server start
  * kubeadm: fix a bug where the static pod changes detection logic is inconsistent with kubelet
  * Update CHANGELOG/CHANGELOG-1.24.md for v1.24.14
  * vclib: Modify x509.UnknownAuthorityError unwrap check
  * vsphere: Adapt to govmomi version bumps
  * *: Bump version of vmware/govmomi
* Mon Jun 12 2023 priyanka.saggu@suse.com
- Update BuildRequires:  `go >= 1.19.9`
- Update to version 1.24.14:
  * Release commit for Kubernetes v1.24.14
  * [1.24] vendor: bump runc to 1.1.6
  * benchmark test to evaluate the overhead of podMatchesScopeFunc
  * Fix incorrect calculation for ResourceQuota with PriorityClass as its scope
  * releng/go: Update images, dependencies and version to Go 1.19.9
  * Fix directory mismatch for `volume.SetVolumeOwnership()`
  * use case-insensitive header keys for http probes
  * add log includes pod preemption details
  * fix: the volume is not detached after the pod and PVC objects are deleted
  * Bump konnectivity-client to 0.0.37
  * Do not look at VPC-related resources outside the cluster's network
  * kubelet: Do not mutate pods in the pod manager
  * Logging, remove LookPath in detectSafeNotMountedBehavior
  * Take canSafelySkipMountPointCheck package-private, reduce log visibility for removePath.
  * Add test for detectSafeNotMountedBehavior.
  * Add test for CanSafelySkipMountPointCheck
  * Correct detection of 'not mounted' behavior -- umount will exit with a non-zero code.
  * Skip mount point checks when possible during mount cleanup.
  * Return error for localhost seccomp type with no localhost profile defined
* Thu Jun  8 2023 priyanka.saggu@suse.com
  Security Patch Fix for CVE-2023-2727 (bsc#1211630) and CVE-2023-2728 (bsc#1211631)
  * added patch: kube-apiserver-admission-plugin-policy.patch
  * this new kube-apiserver component patch prevents ephemeral containers:
  * * from using an image that is restricted by ImagePolicyWebhook (CVE-2023-2727)
  * * from bypassing the mountable secrets policy enforced by the ServiceAccount admission plugin (CVE-2023-2728)
* Thu Apr 27 2023 priyanka.saggu@suse.com
- Update `Requires` in the "kubernetes1.24-client" pkg to:
  * Requires: kubernetes%%{baseversion}-client-common
- Remove following `Obsoletes` from the "kubernetes1.24-client-common" pkg:
  * Obsoletes: kubernetes%%{baseversionminus1}-client-common
* Thu Apr 13 2023 priyanka.saggu@suse.com
- Update to version 1.24.13:
  * Release commit for Kubernetes v1.24.13
  * releng/go: Update images, dependencies and version to Go 1.19.8
  * wait again on pending state
  * cacher allow context cancellation if not ready
  * Drop development dependencies from test targets
  * apiserver cacher: don't accept requests if stopped
  * Clear front proxy headers after authentication is complete
  * Make prerelease tag optional in CI versions
  * Annotate CI version regexes
  * Drop unused regex grouping
  * Delete unused version regex function
  * kubelet: Fix fs quota monitoring on volumes
  * fsquota: only generate pod uuid is nil
  * Change where transformers are called.
  * Route controller should update routes with NodeIP changed When a node reboots or kubelet restarts, it is possible that its IP is changed. In this case, node route should be updated with the correct IP. In this PR, it checks if the IP in an existing route is the same as the actual one. If not, it marks it as "update" so the old route will be deleted and a new one will be created. There's a new field EnableNodeAddresses, which is a feature gate for specific cloud providers to enable after they update their cloud provider code for CreateRoute().
  * client-go/cache: update Replace comment to be more clear
  * client-go/cache: rewrite Replace to check queue first
  * client-go/cache: merge ReplaceMakesDeletionsForObjectsInQueue tests
  * client-go/cache: fix missing delete event on replace without knownObjects
  * client-go/cache: fix missing delete event on replace
  * Bump konnectivity-client to v0.0.36
  * test: demote service ClientIP affinity timeout tests from conformance
* Wed Apr 12 2023 priyanka.saggu@suse.com
- add kubernetes1.18-client-common as conflicts with kubernetes-client-bash-completion
* Mon Mar 27 2023 rombert@apache.org
- Stronger conflicts for completion packages
* Mon Mar 27 2023 rombert@apache.org
- Add proper obsoletes for completion packages
* Tue Mar 21 2023 priyanka.saggu@suse.com
- Update to version 1.24.12:
  * Release commit for Kubernetes v1.24.12
  * One lock among PodNominator and SchedulingQueue
  * releng/go: Update images, dependencies and version to Go 1.19.7
  * Fix for windows kube-proxy: 'externalTrafficPolicy: Local' results in no clusterIP entry in windows node.
  * Re-enable label selector
  * Add integration test for diff --prune --selector
  * Use label selector for filtering out resources when pruning. Matches same behavior as for kubectl apply
  * scheduler/framework/plugins/volumebinding: fix inaccurate log for when a volume is bound to a claim
  * Remove check for CSI driver running on node for CSI migration attach operations
  * Simplify construction of /metrics request
  * Move CSI json file saving to SetUpAt()
  * Fix for issue with Loadbalancer policy creation for IPV6 endpoints in Dualstack mode.
  * Invoke gimme from kube::golang::verify_go_version
  * Defer builds to test-cmd and test-integration targets
  * Carefully compute request path for metrics
* Wed Mar 15 2023 rombert@apache.org
-  Split individual completions into separate packages
* Thu Mar  9 2023 rombert@apache.org
- Use upstream fish completions and obsolete external package
* Thu Mar  2 2023 priyanka.saggu@suse.com
- update patch files to reflect upstream registry changes from k8s.gcr.io to registry.k8s.io
  * kubeadm-opensuse-registry.patch
  * revert-coredns-image-renaming.patch
* Thu Mar  2 2023 priyanka.saggu@suse.com
- Update to version 1.24.11:
  * Release commit for Kubernetes v1.24.11
  * releng: Update images, dependencies and version to Go 1.19.6
  * Update golang.org/x/net to v0.7.0
  * Pin golang.org/x/net to v0.4.0 in 1.24
  * kubelet/client: collapse transport wiring onto standard approach
  * apiserver: remove 34s from DELETECOLLECTION rest handler
  * update prev succeeded indexes for indexed jobs unconditionally
  * use custom dialer for http probes
  * use custom dialer for tcp probes
  * add custom dialer optimized for probes
  * bump honnef.co/go/tools to support go1.20
  * Fix issue that Audit Server could not correctly encode DeleteOption
  * Do not include scheduler name in the preemption event message
  * Do not leak cross namespace pod metadata in preemption events
  * pkg/controller/job: re-honor exponential backoff
  * releng: Update images, dependencies and version to Go 1.19.5
  * Explicitly call rand.Seed() method
  * Improve vendor verification works for each staging repo
  * Bump Konnectivity to v0.0.35
  * Add pod to dsw if termination is not completed during reconstruction #issues/113979
  * integration: migrate taint tests
  * integration: migrate scoring tests
  * integration: migrate preemption tests
  * integration: migrate plugings tests
  * integration: migrate extender tests
  * integration: scheduler: migrate PDB from v1beta1 to v1
  * Fix issues in volumesnapshot test for ephemeral storage
  * update golangci-lint for go 1.19
  * golang: Update to 1.19
  * Adjust for os/exec changes in 1.19
  * Update golangci-lint to 1.46.2 and fix errors
  * Windows Kube-Proxy implementation for internal traffic policy.
  * Fix a regression that scheduler always go through all Filter plugins
  * Fix SPDY proxy authentication with special chars
  * Creating Ingress IP loadbalancer alone when all the endpoints are terminating. KEP1669
  * change k8s.gcr.io/pause to registry.k8s.io/pause
  * Update golang.org/x/net 1e63c2f
  * image pull event include duration with waiting
  * kubelet: make the image pull time more accurate in event
  * update structured-merge-diff to 4.2.3
  * regression test for exponential recursion bug on CRDs
  * Fix endpoint reconciler failing to delete masterlease
  * kubeadm: remove v1.25 etcd "3.5.6-0" for v1.24
  * use etcd 3.5.6-0 after promotion
  * changelog: CVE-2022-3294 and CVE-2022-3162 were fixed in v1.23.14
  * upgrade system-validators to v1.8.0 for a bugfix of cgroupv2 io check
  * Introducing LoadbalancerPortMapping flags for VipExternalIP
  * egress_selector: prevent goroutines leak on connect() step.
  * Merge pull request #113133 from sxllwx:automated-cherry-pick-of-#113133-upstream-release-1.25
  * Fixed (CVE-2022-27664) Bump golang.org/x/net to v0.1.1-0.20221027164007-c63010009c80
  * Add CVE-2022-3162 to CHANGELOG-1.24.md
  * tls.Dial() validates hostname, no need to do that manually
  * e2e: use custom timeouts in GetSnapshotContentFromSnapshot()
  * test/e2e/storage: replace hardcoded value with custom timeout in cleanup routine
  * StatefulSet: Cleanup the complex defer function updating the status
  * Be sure to update the status of StatefulSet even if the new replica creation fails
  * added retries to winkernel proxy rules deletion
  * added backend hashing to winkernel proxier
  * kubelet: fix pod log line corruption when using timestamps and long lines
  * kubeadm: mutate ClusterConfiguration.imageRepository to "registry.k8s.io"
  * kubeadm: use registry.k8s.io instead of k8s.gcr.io
  * add GetAllocatableCPUs test in cpumanager
  * fix GetAllocatableCPUs in cpumanager
  * e2e: restore volume lifecycle checks for csi-hostpath driver
  * kubelet: fix volume reconstruction for CSI ephemeral volumes
  * NodeLifecycleController: Remove race condition
  * kube-proxy wait for cluster cidr skip delete events
  * kube-proxy handle node PodCIDR changs
  * kube-proxy: gate topology correctly
  * service update event should be triggered when appProtocol in port is changed.
  * filter out terminated containers in cadvisor_stats_provider
  * Fix winkernel proxier setting the wrong HNS loadbalancer ID for ingress IP
  * Bump konnectivity-client to v0.0.33
  * Fix list estimator for lists that are executed as gets
  * kubeadm: allow RSA and ECDSA format keys in preflight check
  * Limit redirect proxy handling to redirected responses
  * Make sure auto-mounted subpath mount source is already mounted
  * Call SetupDevice only if Volume is not globally Mounted
  * Fixes kubelet log compression on Windows
  * Add zone field to vsphere test cloudconfig
  * Reduce default gzip compression level from 4 to 1 in apiserver
  * exec auth: support TLS config caching
  * Add an option for aggregator
  * Update go-runner to v2.3.1-go1.18.6-bullseye.0
  * Update kube-cross image to v1.24.0-go1.18.6-bullseye.0
  * Fix problem in updating VolumeAttached in node status
  * Call queueSet::boundNextDispatchLocked enough
  * Always log APF InitialSeats and FinalSeats values
  * Marshal MicroTime to json and proto at the same precision
  * Windows: ensure runAsNonRoot does case-insensitive comparison on user name
  * Tolerate sub-microsecond eventTime changes on update
  * Improve kubectl display of invalid errors
  * fix unmatch reason when updating pod status
  * fix nestedPendingOperations mount and umount parallel bug
  * client-go/rest: check if url is nil to prevent nil pointer dereference
  * Revert "client-go: remove no longer used finalURLTemplate"
  * Skip "instance not found" error for LB backend address pools
  * Update cel-go to v0.10.2.
  * fix a memory leak problem when calling DryRunPreemption
  * Fix JobTrackingWithFinalizers when a pod succeeds after the job fails
  * Use CheckAndMarkAsUncertainViaReconstruction for uncertain volumes
  * Remove volume from found during reconstruction if mounted
  * Add unit test for verifying if processReconstructedVolumes works as expected
  * Fix code to process volumes which were skipped during reconstruction
  * Keep track of each pod that uses a volume during reconstruction
  * allow namespace admins to use leases to encourage migration off of configmaps
  * Fix: filter out unsatisfied nodes when calling AddPod in PodTopologySpread
  * Fix `kubeadm upgrade plan` issue with FQDN nodes names
  * Add rate limiting when calling STS assume role API
  * Fix kubelet panic when accessing metrics/resource endpoint
  * Fixing issue in generatePodSandboxWindowsConfig for hostProcess containers by where pod sandbox won't have HostProcess bit set if pod does not have a security context but containers specify HostProcess.
  * Add retry logic for Unix Domain sockets on Windows
  * Execute the Run function of kubelet, no log output after failure
  * Prune defaults for CRD serving
* Tue Jul 19 2022 jkowalczyk@suse.com
- Update to version 1.24.3:
  * Do not skip job requeue in conflict error
  * kubeadm: fix the bug that configurable KubernetesVersion not respected during kubeadm join
  * endpointslices: node missing on Pod scenario
  * fix metrics for placeholder slice
  * fix a bug on endpointslices tests comparing the wrong metrics
  * kubeadm: fix the bug that configurable KubernetesVersion not respected during kubeadm join
  * GIT-110239: fix activeDeadlineSeconds enforcement bug
  * kubeadm: handle dup unix:// prefix in node annotaiton
  * fix: --chunk-size with selector returns missing result
  * Fix unnecessary recreation of placeholder EndpointSlice
  * kubeadm: fix error adding extra prefix unix://
  * e2e: add storage capability for offline volume expansion
  * add missing error handling steps
  * Update CHANGELOG/CHANGELOG-1.24.md for v1.24.2
  * apiserver: printers should use int64
  * fix image pulling failure when IMDS is unavailalbe in kubelet startup
  * e2e: ensure single image for populator containers
  * fix: exclude non-ready nodes and deleted nodes from azure load balancers
- Require only BuildRequires: golang(API) = 1.18 pinned Go major version.
  Remove potentially conflicting BuildRequires: go >= x.y.z.
  The plan for future updates is BuildRequires: golang(API) >= 1.18
  minimum Go major version.
* Wed Jun 22 2022 jkowalczyk@suse.com
- Update to version 1.24.2:
  * move the ignore logic higher up to the reconciler
  * Ignore EndpointSlices that are already marked for deletion
  * test: update graceful node shutdown e2e with watch
  * kubelet: Mark ready condition as false explicitly for terminal pods
  * agnhost: bump version 2.39
  * Update Go to 1.18.3
  * add service e2e tests
  * kubelet: add e2e test to verify probe readiness
  * kubelet: only shutdown probes for pods that are terminated
  * kubelet: Pod probes should be handled by pod worker
  * cpu manager policy set to none, no one remove container id from container map, lead memory leak
  * fix audit union loop variables in closures
  * Updating e2e test to check EndpointSlices and Endpoints as well
  * e2e: services with evicted pods doesn't have endpoints
  * e2e test for evicted pods
  * endpoints controller: don't consider terminal endpoints
  * endpointslices: terminal pods doesn't receive enpoints
  * add pod util to verify pod is terminal
  * Update CHANGELOG/CHANGELOG-1.24.md for v1.24.1
  * Add test for checking ephemeral volume expansion
  * Fix resizing of ephemeral volumes
  * Winkernel proxier cache HNS data to improve syncProxyRules performance
  * GCE Windows: Copy the CNI binaries from the right folder
* Tue Jun 21 2022 jkowalczyk@suse.com
- Update to version 1.24.1:
  * kubeadm: remove checking legacy taint for kubeadm-kinder-latest-on-1-24
  * Fix requests scope classification
  * Update Go to 1.18.2
  * Integration test for openapi scale & status
  * Remove warning log for merging meta and scale type
  * authn: fix cache mutation by AuthenticatedGroupAdder
  * GCE: skip updating and deleting external loadbalancers if service is managed outside of service controller
  * Wait for cache to sync in job's TestWatchOrphanPods
  * Fix ServiceIPStaticSubrange assigns duplicate IP addresses
  * Fix OpenAPI loading error caused by empty APIService
  * kubeadm: only taint CP nodes when the legacy "master" taint is present
  * Test Foreground deletion in job integration
  * Fix removing finalizer from finished jobs
  * Don't mark job as failed until expectations are satisfied
  * Integration test for backoff limit and finalizers
  * Update CHANGELOG/CHANGELOG-1.24.md for v1.24.0
  * Do not wrap lines if we can't read term size
* Thu May  5 2022 jkowalczyk@suse.com
- Initial package
